package com.perfectech.cts;

import android.content.Context;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.TimeZone;

/**
 * Created by jnissley on 7/28/15.
 */
public class DateConvertClass {
    private static final String sDBName = "CTS.db";
    private static final int iVersionVal = 5;
    private static String DateFormats[] = {
        "MM/dd/yyyy HH:mm",
        "MM/dd/yyyy hh:mm aa",
        "dd/MM/yyyy HH:mm",
        "dd/MM/yyyy hh:mm aa"
    };
    public Context oContext = null;

    public String GMTToLocal(String sDate) {
        String sReturnDate = "";
        Integer iFormat;
        try {
            DBParameters oDBParameters = new DBParameters();
            String sFormat = oDBParameters.readParameter("DateFormat", oContext, sDBName, iVersionVal);
            iFormat = Integer.parseInt(sFormat);
        } catch (Exception ex) {
            DBLogs.insert("Date Pref Exception: " + ex.toString(),
                    "DateConvertClass.GMTToLocal(1)",
                    oContext, sDBName, iVersionVal);
            iFormat = 0;
        }
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date dGMTDate = sdf.parse(sDate);
            long lEpochGMT = dGMTDate.getTime();
            TimeZone tz = TimeZone.getDefault();
            Calendar cal = GregorianCalendar.getInstance(tz);
            int offsetInMillis = tz.getOffset(cal.getTimeInMillis());
            long lEpochLocal = lEpochGMT + offsetInMillis;
            SimpleDateFormat sdfLocal = new SimpleDateFormat(DateFormats[iFormat]);
            sReturnDate = sdfLocal.format(new Date(lEpochLocal));
        } catch (ParseException ex) {
            DBLogs.insert("Date Exception: " + ex.toString(),
                    "DateConvertClass.GMTToLocal(2)",
                    oContext, sDBName, iVersionVal);
            sReturnDate = "Invalid";
        }
        return sReturnDate;
    }

    public String LocalToGMT(String sDate) {
        String sReturnDate = "";
        Integer iFormat;
        try {
            DBParameters oDBParameters = new DBParameters();
            String sFormat = oDBParameters.readParameter("DateFormat", oContext, sDBName, iVersionVal);
            iFormat = Integer.parseInt(sFormat);
        } catch (Exception ex) {
            DBLogs.insert("Date Pref Exception: " + ex.toString(),
                    "DateConvertClass.LocalToGMT(1)",
                    oContext, sDBName, iVersionVal);
            iFormat = 0;
        }
        try {
            SimpleDateFormat sdf = new SimpleDateFormat(DateFormats[iFormat]);
            Date dLocalDate = sdf.parse(sDate);
            long lEpochLocal = dLocalDate.getTime();
            TimeZone tz = TimeZone.getDefault();
            Calendar cal = GregorianCalendar.getInstance(tz);
            int offsetInMillis = tz.getOffset(cal.getTimeInMillis());
            long lEpochGMT = lEpochLocal - offsetInMillis;
            SimpleDateFormat sdfGMT = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            sReturnDate = sdfGMT.format(new Date(lEpochGMT));
        } catch (ParseException ex) {
            DBLogs.insert("Date Exception: " + ex.toString(),
                    "DateConvertClass.LocalToGMT(2)",
                    oContext, sDBName, iVersionVal);
            sReturnDate = "Invalid";
        }
        return sReturnDate;
    }

    /* This is the format that will be used for all time date items placed into the database
       All timestamps should be gmt so we can always display the time correctly for the timezone
       the phone is in.
     */
    public String GMTTimestamp() {
        String sTimeStamp = "";
        //Get the epoch value for now
        long lEpochLocal = new Date().getTime();
        TimeZone tz = TimeZone.getDefault();
        Calendar cal = Calendar.getInstance(tz);
        //Get the milisecond offset between gmt and the phone time
        int offsetInMillis = tz.getOffset(cal.getTimeInMillis());
        long lEpochGMT = lEpochLocal - offsetInMillis;
        SimpleDateFormat sdfGMT = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        sTimeStamp = sdfGMT.format(new Date(lEpochGMT));
        return sTimeStamp;
    }
}
