package com.perfectech.cts.activities;

import android.app.AlertDialog;
import android.content.ContentValues;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;
import android.content.DialogInterface.OnClickListener;
import android.view.inputmethod.InputMethodManager;
import android.os.Handler;

import com.perfectech.cts.DBLogs;
import com.perfectech.cts.DBParameters;
import com.perfectech.cts.DateConvertClass;
import com.perfectech.cts.JobListTextViewListAdapter;
import com.perfectech.cts.objects.Jobs;
import com.perfectech.cts.R;
import com.perfectech.cts.CTSDBHelper;

import org.json.JSONArray;
import org.json.JSONObject;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;


public class JobsCenter extends AppCompatActivity {

    private static final String sDBName = "CTS.db";
    private static final int iVersionVal = 5;
    private static String sAndroidID = "";
    private static String sUserID = "";
    private static ArrayList<ArrayList<String>> jobArray;
    private Handler oHandler = new Handler();
    private static String sClosedDays = "2"; //days of closed jobs to show

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_jobs_center);

        SharedPreferences prefs = getSharedPreferences("CTSSharedPrefs",
                Context.MODE_PRIVATE);
        SharedPreferences.Editor editor = prefs.edit();
        String sLoggedInUserCompany = prefs.getString("LoggedInUserCompany", "No Value");
        sUserID = prefs.getString("UserID", "No Value");
        TextView otvUserName = (TextView) findViewById(R.id.tvUserName);
        otvUserName.setText(sLoggedInUserCompany.substring(0,sLoggedInUserCompany.indexOf('-')));

        String sCurrentVersion = prefs.getString("CTSVersion", "No Value");
        TextView otvCopyright = (TextView) findViewById(R.id.tvCopyright);
        String sVersionText = otvCopyright.getText().toString();
        // need to replace the %RELNUM% with the actual rel version
        sVersionText = sVersionText.replace("RELNUM", sCurrentVersion);
        otvCopyright.setText(sVersionText);

        Button btnReqJob = (Button) findViewById(R.id.btnReqJob);
        btnReqJob.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                try {
                    InputMethodManager imm = (InputMethodManager) getSystemService(INPUT_METHOD_SERVICE);
                    imm.hideSoftInputFromWindow(getCurrentFocus().getWindowToken(), 0);
                } catch (Exception e) {
                    // TODO: handle exception
                }
                reqJobs();
                getJobsFromDB();
            }
        });
        oHandler.post(timedTask);
    }

    @Override
    public void onResume()
    {
        super.onResume();
        updateUI();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_jobs_center, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }
        if (id == R.id.action_logout) {
            finish();
            Intent i = new Intent(getApplicationContext(), CTSActivity.class);
            startActivity(i);
            return true;
        }
        if (id == R.id.action_icon_meanings) {
            Intent i = new Intent(getApplicationContext(), HelpActivity.class);
            i.putExtra("ScreenID", "IconMeanings");
            startActivity(i);
            return true;
        }
        if (id == R.id.action_help) {

             // display a full page
            Intent i = new Intent(getApplicationContext(), HelpActivity.class);
            i.putExtra("ScreenID", "JobsCenter");
            startActivity(i);

            return true;
        }
        if (id == R.id.action_about) {
            Intent i = new Intent(getApplicationContext(), AboutActivity.class);
            startActivity(i);
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    private Runnable timedTask = new Runnable() {
        @Override
        public void run() {
            // TODO Auto-generated method stub
            updateUI();
            oHandler.postDelayed(timedTask, 20000);
        }
    };

    /*****************************************************************************************/
    /* This method will get the number of available jobs */

    /**
     * *************************************************************************************
     */
    private void getJobsFromDB() {
        CTSDBHelper oDB = new CTSDBHelper(getApplicationContext(), sDBName,
                null, iVersionVal);
        try {
            oDB.createDataBase();
        } catch (IOException ioe) {
            throw new Error("Unable to create database");
        }

        oDB.openDataBase();
        //Select all jobs that are not declined and have not been closed for more than
        //sClosedDays old
        try {
            DateConvertClass oDateConvertClass = new DateConvertClass();
            oDateConvertClass.oContext = getApplicationContext();
            String sCurrentDateTime = oDateConvertClass.GMTTimestamp();
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date messageDate = dateFormat.parse(sCurrentDateTime);
            long ldayMillis = 86400000;
            Date fromDate = new Date(messageDate.getTime() - (ldayMillis * Integer.parseInt(sClosedDays)));
            String sfromDate = dateFormat.format(fromDate);
            String sSQL = "select * from jobs where job_status_id <> 9 and job_status_id <> 6 and job_status_id <> 11 ";
            //sSQL += "union select * from jobs where job_status_id = 6 ";
            //sSQL += "and date_time > '" + sfromDate + "'";

            Log.d("sSQL", sSQL);

            jobArray = oDB.selectRecordsFromDBList(sSQL, null);
            oDB.close();
        }catch (Exception ex) {
            DBLogs.insert("Database Exception " + ex.getMessage(),
                    "JobsCenter.getJobsFromDB",
                    getApplicationContext(), sDBName, iVersionVal);
        }

        ListView jobs = (ListView) this
                .findViewById(R.id.lvOpenJobsList);

        //SimpleAdapter sd;
        ArrayList<Jobs> allJobs = new ArrayList<Jobs>();
        Integer iSize = jobArray.size();
        Log.d("iSize", iSize.toString());
        DateConvertClass oDateConvertClass = new DateConvertClass();
        oDateConvertClass.oContext = getApplicationContext();
        if (iSize > 0) {
            for (ArrayList<String> sValue : jobArray) {
                Jobs jobObj = new Jobs();
                jobObj.job_id = sValue.get(1);
                jobObj.job_status_id = sValue.get(3);
                //Convert the GMT database time to local device time
                jobObj.date_time = oDateConvertClass.GMTToLocal(sValue.get(2));
                jobObj.status_name = sValue.get(4);
                jobObj.assigned_id = sValue.get(5);
                jobObj.importer_id = sValue.get(19);
                jobObj.importer_name = sValue.get(20);
                jobObj.manifest_num = sValue.get(6);
                jobObj.container_num = sValue.get(7);
                jobObj.delivery_address_line1 = sValue.get(8);
                jobObj.delivery_address_line2 = sValue.get(9);
                jobObj.delivery_city = sValue.get(10);
                jobObj.delivery_state = sValue.get(11);
                jobObj.delivery_postal_code = sValue.get(12);
                jobObj.pickup_address_line1 = sValue.get(13);
                jobObj.pickup_address_line2 = sValue.get(14);
                jobObj.pickup_city = sValue.get(15);
                jobObj.pickup_state = sValue.get(16);
                jobObj.pickup_postal_code = sValue.get(17);
                jobObj.username = sValue.get(18);
                jobObj.job_num = sValue.get(21);
                jobObj.pickup_date_time = oDateConvertClass.GMTToLocal(sValue.get(23));
                jobObj.delivery_date_time = oDateConvertClass.GMTToLocal(sValue.get(24));
                jobObj.ref_note = sValue.get(25);
                allJobs.add(jobObj);
            }

            //jobs.setAdapter(new JobListTextViewListAdapter(this,R.layout.jobs_row, null));
            jobs.setAdapter(new JobListTextViewListAdapter(this, R.layout.jobs_row, allJobs));
            jobs.setOnItemClickListener(new ListView.OnItemClickListener() {
                public void onItemClick(AdapterView<?> parent, View view,
                                        int position, long id) {
                    try {
                        // get the selected row's ticket number
                        Integer iCounter = 0;
                        for (ArrayList<String> sValue : jobArray) {
                            if (position == iCounter) {
                                Log.d("SelectedJobID", sValue.get(0));
                                selectJobs(sValue.get(0));
                            }
                            iCounter++;
                        }
                    } catch (Exception e) {
                        Log.d("Error:", e.toString());
                    }
                }
            });

        } else {
            // No open tickets found
            Log.d("getJobs", "No Messages");
            String[] openTicketsArray = new String[]{"No Open Jobs"};
            jobs.setAdapter(new ArrayAdapter<String>(this,
                    android.R.layout.simple_list_item_1, openTicketsArray));
        }

    }
    /********************************************************************************/
    /* Handle the selection of a message */

    /**
     * ****************************************************************************
     */
    private void selectJobs(final String sJobID) {
        // call the jobs_detail_activity and pass in the selected job_id
        Intent i = new Intent(getApplicationContext(),
                JobsDetailActivity.class);
        i.putExtra("JobID", sJobID);
        startActivity(i);
        //finish();
    }

    /********************************************************************************/
	/* Handle the selection of a message */

    /**
     * ****************************************************************************
     */
    private void reqJobs() {

        // get the reqJobID
        String sReqJobID = "";
        EditText etReqJobID = (EditText) findViewById(R.id.editJobID);
        sReqJobID = etReqJobID.getText().toString();

        // needs to make sure that there is a reqJobID or do't let them go on
        if (sReqJobID.length() < 1) {
            new AlertDialog.Builder(JobsCenter.this)
                    .setTitle("Required Input")
                    .setMessage("Please enter a valid Job Number")
                    .setCancelable(false)
                    .setPositiveButton("OK", new OnClickListener() {
                        @Override
                        public void onClick(DialogInterface dialog, int which) {
                            dialog.cancel();
                        }
                    }).create().show();
            etReqJobID.setText("");
        } else {

            // need to make sure we don't already have the job number on the device
            if (jobReqAlready()) {
                new AlertDialog.Builder(JobsCenter.this)
                        .setTitle("Requested Job Number")
                        .setMessage("The requested Job Number is already on the device and in your Job Queue.")
                        .setCancelable(false)
                        .setPositiveButton("OK", new OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialog, int which) {
                                dialog.cancel();
                            }
                        }).create().show();
                etReqJobID.setText("");
            } else {
                String data = "";
                DBParameters oDBParameters = new DBParameters();
                etReqJobID.setText("");

                // WebServer Request URL
                String serverURL = oDBParameters.readParameter(
                        "REST_BASE_URL", getApplicationContext(), sDBName,
                        iVersionVal); //"http://androidexample.com/media/webservice/JsonReturn.php";

                serverURL += "jobReqSync.php";


                try {
                    // Set Request parameter
                    data += "&" + URLEncoder.encode("reqJobID", "UTF-8") + "=" + sReqJobID;
                    data += "&" + URLEncoder.encode("reqUserID", "UTF-8") + "=" + sUserID;
                } catch (UnsupportedEncodingException e) {
                    // TODO Auto-generated catch block
                    e.printStackTrace();
                }

                /************ Make Post Call To Web Server ***********/
                BufferedReader reader = null;
                StringBuilder sb = new StringBuilder();

                // Send data
                try {

                    // Defined URL  where to send data
                    URL url = new URL(serverURL);

                    // Send POST data request
                    URLConnection conn = url.openConnection();
                    conn.setDoOutput(true);
                    OutputStreamWriter wr = new OutputStreamWriter(conn.getOutputStream());
                    wr.write(data);
                    wr.flush();

                    // Get the server response
                    reader = new BufferedReader(new InputStreamReader(conn.getInputStream()));
                    String line = null;

                    // Read Server Response
                    while ((line = reader.readLine()) != null) {
                        // Append server response in string
                        sb.append(line + "");
                    }
                } catch (Exception ex) {
                    ex.printStackTrace();
                    Log.e("SyncJobs Error:", ex.toString());
                } finally {
                    try {
                        reader.close();
                    } catch (Exception ex) {
                    }
                }

                if (sb.length() < 5) {
                    displayAlertDialog("Requested Job Number Found","Requested Job Number: " + sReqJobID + " was not found on the server.");
                }

                // put the information into the database
                CTSDBHelper oDB = new CTSDBHelper(getApplicationContext(), sDBName, null, iVersionVal);
                try {
                    oDB.createDataBase();
                } catch (IOException ioe) {
                    throw new Error("Unable to create database");
                }

                oDB.openDataBase();

                try {
                    JSONArray oJsonArray = new JSONArray(sb.toString());

                    for (int iCounter = 0; iCounter < oJsonArray.length(); iCounter++) {

                        JSONObject json = oJsonArray.getJSONObject(iCounter);
                        ContentValues oValues = new ContentValues();
                        oValues.put("job_id", json.getString("job_id"));
                        oValues.put("job_status_id", json.getString("job_status_id"));
                        oValues.put("date_time", json.getString("date_time"));
                        oValues.put("status_name", json.getString("status_name"));
                        oValues.put("assigned_id", json.getString("assigned_id"));
                        oValues.put("manifest_num", json.getString("manifest_num"));
                        oValues.put("container_num", json.getString("container_num"));
                        oValues.put("delivery_address_line1", json.getString("delivery_address_line1"));
                        oValues.put("delivery_address_line2", json.getString("delivery_address_line2"));
                        oValues.put("delivery_city", json.getString("delivery_city"));
                        oValues.put("delivery_state", json.getString("delivery_state"));
                        oValues.put("delivery_postal_code", json.getString("delivery_postal_code"));
                        oValues.put("delivery_phone", json.getString("delivery_phone"));
                        oValues.put("delivery_email_address", json.getString("delivery_email_address"));
                        oValues.put("pickup_address_line1", json.getString("pickup_address_line1"));
                        oValues.put("pickup_address_line2", json.getString("pickup_address_line2"));
                        oValues.put("pickup_city", json.getString("pickup_city"));
                        oValues.put("pickup_state", json.getString("pickup_state"));
                        oValues.put("pickup_postal_code", json.getString("pickup_postal_code"));
                        oValues.put("pickup_phone", json.getString("pickup_phone"));
                        oValues.put("pickup_email_address", json.getString("pickup_email_address"));
                        oValues.put("username", json.getString("username"));
                        oValues.put("importer_id", json.getString("importer_id"));
                        oValues.put("importer_name", json.getString("importer_name"));
                        oValues.put("job_num", json.getString("job_num"));
                        oValues.put("pickup_order_doc_name", json.getString("pickup_order_doc_name"));
                        oValues.put("pickup_date_time", json.getString("pickup_date_time"));
                        oValues.put("delivery_date_time", json.getString("delivery_date_time"));
                        oValues.put("ref_note", json.getString("ref_note"));
                        oValues.put("cargo_weight", json.getString("cargo_weight"));
                        oValues.put("measurement_type_id", json.getString("measurement_type_id"));
                        oValues.put("pickup_signature_name", json.getString("pickup_signature_name"));
                        oValues.put("delivery_signature_name", json.getString("delivery_signature_name"));

                        try {
                            oDB.insertRecordsInDB("jobs", null, oValues);
                        } catch (Exception sqlEx) {
                            Log.e("sqlEx:", sqlEx.toString());
                        }
                    }
                } catch (Throwable t) {
                    Log.d("getJobs():", t.toString());
                } finally {
                    oDB.close();
                }
            }
        }
    }

    private boolean jobReqAlready() {
        boolean bRtnVal = false;
        CTSDBHelper oDB = new CTSDBHelper(getApplicationContext(), sDBName,
                null, iVersionVal);
        try {
            oDB.createDataBase();
        } catch (IOException ioe) {
            throw new Error("Unable to create database");
        }

        EditText etReqJobID = (EditText) findViewById(R.id.editJobID);
        String sReqJobID = etReqJobID.getText().toString();

        oDB.openDataBase();
        String sSQL = "Select * ";
        sSQL += "from jobs ";
        sSQL += " where job_num = '" + sReqJobID + "' COLLATE NOCASE";

        Log.d("sSQL", sSQL);

        jobArray = oDB.selectRecordsFromDBList(sSQL, null);

        // closes the database
        try {
            oDB.close();
        } catch (Throwable e) {
            e.printStackTrace();
        }

        Integer iSize = jobArray.size();
        Log.d("iSize", iSize.toString());
        if (iSize > 0) {
            for (ArrayList<String> sValue : jobArray) {
                bRtnVal = true;
            }
        }
        return bRtnVal;
    }

    private void displayAlertDialog(String sTitle, String sMessage) {
        new AlertDialog.Builder(this)
                .setTitle(sTitle)
        .setMessage(sMessage)
        .setPositiveButton(android.R.string.ok, new DialogInterface.OnClickListener() {
            public void onClick(DialogInterface dialog, int which) {
                dialog.cancel();
            }
        })
        .show();
    }

    private void updateUI() {
        // get the current messages in the DB and display them in the list view
        getJobsFromDB();
    }
}
