package com.perfectech.cts.syncClasses;

import android.app.Activity;
import android.app.Notification;
import android.app.NotificationManager;
import android.content.ContentValues;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.drawable.Drawable;
import android.util.Log;

import com.perfectech.cts.DBLogs;
import com.perfectech.cts.DBParameters;
import com.perfectech.cts.DateConvertClass;
import com.perfectech.cts.R;
import com.perfectech.cts.CTSDBHelper;
import com.perfectech.cts.objects.Jobs;
import com.perfectech.cts.webServices.SyncFiles;
import com.perfectech.cts.webServices.SyncJson;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.net.URL;
import java.net.URLConnection;
import java.util.ArrayList;

/**
 * Created by jcairns on 5/14/15.
 */
public class SyncJobs {

    private static final int TIMEOUT_MILLISEC = 600;
    private static final String sDBName = "CTS.db";
    public static Activity inActivity;
    public static Context oContext;
    public static String sUserName;
    private static final int iVersionVal = 5;

    public static void getJobs() throws Exception {
        String data = "";

        // need to get the last message id that was last syncd from the server
        int iLastSyncJobID = lastJobIdSync();

        DBParameters oDBParameters = new DBParameters();

        // WebServer Request URL
        String serverURL = oDBParameters.readParameter(
                "REST_BASE_URL", oContext, sDBName,
                iVersionVal);

        try {
            SyncJson oGetJobs = new SyncJson();
            oGetJobs.oContext = oContext;
            oGetJobs.webserviceName = "jobSync.php";
            JSONObject oGetJobsObject = new JSONObject();
            oGetJobsObject.put("userName", sUserName);
            oGetJobsObject.put("lastJobId", iLastSyncJobID);
            oGetJobs.sendString = oGetJobsObject.toString();
            data = oGetJobs.SyncData();
        } catch(JSONException ex) {
            DBLogs.insert("JSON Error: " + ex.toString(),
                    "getJobs", oContext,
                    sDBName, iVersionVal);
        }

        //Only go through this if you got something back [] means no new jobs
        if (!data.equals("[]")) {
            // put the information into the database
            CTSDBHelper oDB = new CTSDBHelper(oContext, sDBName, null, iVersionVal);
            try {
                oDB.createDataBase();
            } catch (IOException ioe) {
                throw new Error("Unable to create database");
            }

            oDB.openDataBase();

            Boolean bGotAJob = false;
            Integer iJobCount = 0;

            try {
                JSONArray oJsonArray = new JSONArray(data.toString());

                for (int iCounter = 0; iCounter < oJsonArray.length(); iCounter++) {
                    iJobCount++;
                    JSONObject json = oJsonArray.getJSONObject(iCounter);
                    ContentValues oValues = new ContentValues();
                    oValues.put("job_id", json.getString("job_id"));
                    oValues.put("job_status_id", json.getString("job_status_id"));
                    oValues.put("date_time", json.getString("date_time"));
                    oValues.put("status_name", json.getString("status_name"));
                    oValues.put("assigned_id", json.getString("assigned_id"));
                    oValues.put("manifest_num", json.getString("manifest_num"));
                    oValues.put("container_num", json.getString("container_num"));
                    oValues.put("delivery_address_line1", json.getString("delivery_address_line1"));
                    oValues.put("delivery_address_line2", json.getString("delivery_address_line2"));
                    oValues.put("delivery_city", json.getString("delivery_city"));
                    oValues.put("delivery_state", json.getString("delivery_state"));
                    oValues.put("delivery_postal_code", json.getString("delivery_postal_code"));
                    oValues.put("delivery_phone", json.getString("delivery_phone"));
                    oValues.put("delivery_email_address", json.getString("delivery_email_address"));
                    oValues.put("pickup_address_line1", json.getString("pickup_address_line1"));
                    oValues.put("pickup_address_line2", json.getString("pickup_address_line2"));
                    oValues.put("pickup_city", json.getString("pickup_city"));
                    oValues.put("pickup_state", json.getString("pickup_state"));
                    oValues.put("pickup_postal_code", json.getString("pickup_postal_code"));
                    oValues.put("pickup_phone", json.getString("pickup_phone"));
                    oValues.put("pickup_email_address", json.getString("pickup_email_address"));
                    oValues.put("username", json.getString("username"));
                    oValues.put("importer_id", json.getString("importer_id"));
                    oValues.put("importer_name", json.getString("importer_name"));
                    oValues.put("job_num", json.getString("job_num"));
                    oValues.put("pickup_order_doc_name", json.getString("pickup_order_doc_name"));
                    oValues.put("pickup_date_time", json.getString("pickup_date_time"));
                    oValues.put("delivery_date_time", json.getString("delivery_date_time"));
                    oValues.put("ref_note", json.getString("ref_note"));
                    oValues.put("cargo_weight", json.getString("cargo_weight"));
                    oValues.put("measurement_type_id", json.getString("measurement_type_id"));
                    oValues.put("pickup_signature_name", json.getString("pickup_signature_name"));
                    oValues.put("delivery_signature_name", json.getString("delivery_signature_name"));

                    try {
                        oDB.insertRecordsInDB("jobs", null, oValues);
                        if (oValues.get("pickup_order_doc_name").toString().length() > 2) {
                            String sFilename = oValues.get("pickup_order_doc_name").toString();
                            File fFullpath = new File(getFilePath(), sFilename);

                            if (!fileExists(fFullpath)) {
                                SyncFiles.fFilePath = getFilePath();
                                SyncFiles.oContext = oContext;
                                SyncFiles.sFileName = sFilename;
                                //This is really the server path to the file
                                SyncFiles.sWebService = serverURL + "files/" + sFilename;
                                SyncFiles.downloadFile();
                            }
                        }
                        bGotAJob = true;
                    } catch (Exception sqlEx) {
                        Log.e("sqlEx:", sqlEx.toString());
                    }
                }
            } catch (Throwable t) {
                Log.d("getJobs():", t.toString());
            } finally {
                oDB.close();
            }

            if (bGotAJob) {
                int iJob = 0;
                if (getStatusBarBackgroundLightValue() < 128) {
                    iJob = R.drawable.list_job_menu;
                } else {
                    iJob = R.drawable.list_job;
                }
                Notification noti = new Notification.Builder(oContext)
                        .setContentTitle("C.T.S. New Jobs")
                        .setContentText("You received " + iJobCount + " new Jobs.")
                        .setSmallIcon(iJob).build();

                NotificationManager notificationManager = (NotificationManager) oContext.getSystemService(oContext.NOTIFICATION_SERVICE);

                // hide the notification after its selected
                noti.flags |= Notification.FLAG_AUTO_CANCEL;

                notificationManager.notify(1, noti);
            }
        }
    }

    private static int lastJobIdSync() {
        int iRtnVal = 0;

        // put the information into the database
        CTSDBHelper oDB = new CTSDBHelper(oContext, sDBName, null, iVersionVal);
        try {
            oDB.createDataBase();
        } catch (IOException ioe) {
            throw new Error("Unable to create database");
        }

        oDB.openDataBase();
        String sSQL = "select max(job_id) from jobs";
        ArrayList<ArrayList<String>> sStringList = oDB.selectRecordsFromDBList(
                sSQL, null);
        oDB.close();

        if (sStringList != null) {
            for (int i = 0; i < sStringList.size(); i++) {
                int iSize = sStringList.size();
                ArrayList<String> tempList = sStringList.get(i);
                try {
                    iRtnVal = Integer.parseInt(tempList.get(0));
                } catch (Exception ex) {
                    iRtnVal = 0;
                }
            }
        } else {
            iRtnVal = 0;
        }

        return iRtnVal;
    }

    public static void getJobStatusType() throws Exception {
        String data = "";

        // delete all rows first
        // put the information into the database
        CTSDBHelper oDB = new CTSDBHelper(oContext, sDBName, null, iVersionVal);
        try {
            oDB.createDataBase();
        } catch (IOException ioe) {
            throw new Error("Unable to create database");
        }

        oDB.openDataBase();

        oDB.deleteAllRecords("job_status_type");

        DBParameters oDBParameters = new DBParameters();

        // WebServer Request URL
        String serverURL = oDBParameters.readParameter(
                "REST_BASE_URL", oContext, sDBName,
                iVersionVal); //"http://androidexample.com/media/webservice/JsonReturn.php";

        serverURL += "jobStatusTypeSync.php";

        /************ Make Post Call To Web Server ***********/
        BufferedReader reader = null;
        StringBuilder sb = new StringBuilder();

        // Send data
        try {

            // Defined URL  where to send data
            URL url = new URL(serverURL);

            // Send POST data request
            URLConnection conn = url.openConnection();
            conn.setDoOutput(true);
            OutputStreamWriter wr = new OutputStreamWriter(conn.getOutputStream());
            wr.write(data);
            wr.flush();

            // Get the server response
            reader = new BufferedReader(new InputStreamReader(conn.getInputStream()));
            String line = null;

            // Read Server Response
            while ((line = reader.readLine()) != null) {
                // Append server response in string
                sb.append(line + "");

            }
        } catch (Exception ex) {
            ex.printStackTrace();
            Log.e("SyncJSType Error:", ex.toString());
        } finally {
            try {
                if (reader != null) {
                    reader.close();
                }
            } catch (Exception ex) {
            }
        }

        // put the information into the database
        try {
            JSONArray oJsonArray = new JSONArray(sb.toString());

            for (int iCounter = 0; iCounter < oJsonArray.length(); iCounter++) {

                JSONObject json = oJsonArray.getJSONObject(iCounter);
                ContentValues oValues = new ContentValues();
                oValues.put("id", json.getString("id"));
                oValues.put("name", json.getString("name"));

                try {
                    oDB.insertRecordsInDB("job_status_type", null, oValues);
                } catch (Exception sqlEx) {
                    Log.e("sqlEx:", sqlEx.toString());
                }
            }
        } catch (Throwable t) {
            Log.d("getJobsStatusType():", t.toString());
        } finally {
            oDB.close();
        }
    }

    public static void getgpscoords() throws Exception {
        String data = "";
        CTSDBHelper oDB = new CTSDBHelper(oContext, sDBName, null, iVersionVal);
        try {
            oDB.createDataBase();
        } catch (IOException ioe) {
            throw new Error("Unable to create database");
        }

        oDB.openDataBase();

        // Delete all gps records and reload from server
        oDB.deleteAllRecords("gps_coords");

        DBParameters oDBParameters = new DBParameters();

        // WebServer Request URL
        String serverURL = oDBParameters.readParameter(
                "REST_BASE_URL", oContext, sDBName,
                iVersionVal); //"http://androidexample.com/media/webservice/JsonReturn.php";

        serverURL += "gpsCoordsSync.php";
        /************ Make Post Call To Web Server ***********/
        BufferedReader reader = null;
        StringBuilder sb = new StringBuilder();

        // Send data
        try {

            // Defined URL  where to send data
            URL url = new URL(serverURL);

            // Send POST data request
            URLConnection conn = url.openConnection();
            conn.setDoOutput(true);
            OutputStreamWriter wr = new OutputStreamWriter(conn.getOutputStream());
            wr.write(data);
            wr.flush();

            // Get the server response
            reader = new BufferedReader(new InputStreamReader(conn.getInputStream()));
            String line = null;

            // Read Server Response
            while ((line = reader.readLine()) != null) {
                // Append server response in string
                sb.append(line + "");

            }
        } catch (Exception ex) {
            ex.printStackTrace();
            Log.e("Syncgpscoords Error:", ex.toString());
        } finally {
            try {
                reader.close();
            } catch (Exception ex) {
            }
        }
        // put the information into the database
        try {
            JSONArray oJsonArray = new JSONArray(sb.toString());

            for (int iCounter = 0; iCounter < oJsonArray.length(); iCounter++) {

                JSONObject json = oJsonArray.getJSONObject(iCounter);
                ContentValues oValues = new ContentValues();
                oValues.put("name", json.getString("name"));
                oValues.put("lat", json.getString("lat"));
                oValues.put("long", json.getString("long"));
                oValues.put("isGeofence", json.getInt("isGeofence"));
                oValues.put("isEntry", json.getInt("isEntry"));
                oValues.put("isExit", json.getInt("isExit"));
                oValues.put("gpsGroupName", json.getString("gpsGroupName"));
                oValues.put("radius", json.getString("radius"));
                oValues.put("isInPort", json.getString("isInPort"));
                try {
                    oDB.insertRecordsInDB("gps_coords", null, oValues);
                } catch (Exception sqlEx) {
                    Log.e("sqlEx:", sqlEx.toString());
                }
            }
        } catch (Throwable t) {
            Log.d("getgpscoords():", t.toString());
        } finally {
            oDB.close();
        }
    }
     /*
     This method will check if there are any jobs to sync from the server to the phone
      */
    public static void syncJobs() {
        //Get the list of jobs for this user that need to be updated
        String sJobsToUpdate = "";
        try {
            SyncJson oSyncJobs = new SyncJson();
            oSyncJobs.oContext = oContext;
            oSyncJobs.webserviceName = "jobUpdateList.php";
            JSONObject oSyncJobsObject = new JSONObject();
            oSyncJobsObject.put("userID", sUserName);
            oSyncJobs.sendString = oSyncJobsObject.toString();
            sJobsToUpdate = oSyncJobs.SyncData();
        } catch(JSONException ex) {
            DBLogs.insert("JSON Error: " + ex.toString(),
                    "PickupOrderActivity.acceptDocument", oContext,
                    sDBName, iVersionVal);
        }
        //[] means nothing was returned
        if (!sJobsToUpdate.equals("[]")) {
            try {
                JSONArray oJobsToUpdate = new JSONArray(sJobsToUpdate);
                SyncJson oGetJob = new SyncJson();
                oGetJob.oContext = oContext;
                oGetJob.webserviceName = "getJob.php";
                int iLength = oJobsToUpdate.length();
                for (int i = 0; i < oJobsToUpdate.length(); i++) {
                    oGetJob.sendString = oJobsToUpdate.getString(i);
                    String sJobData = oGetJob.SyncData();
                    UpdateJob(sJobData);
                }
            } catch (JSONException ex) {
                DBLogs.insert("JSON Error: " + ex.toString(),
                        "SyncJobs.syncJobs", oContext,
                        sDBName, iVersionVal);
            }
        }
    }

    /*
    This method works with sync jobs and will update the job that was modified
     */
    private static void UpdateJob(String sJSONJob) {
        try {
            JSONArray oJobArray = new JSONArray(sJSONJob);
            //There is only ever one item in this array so cheating a little
            JSONObject oJob = oJobArray.getJSONObject(0);
            ContentValues oValues = new ContentValues();
            //oValues.put("job_id", oJob.getString("job_id"));
            oValues.put("job_status_id", oJob.getString("job_status_id"));
            oValues.put("date_time", oJob.getString("date_time"));
            oValues.put("status_name", oJob.getString("status_name"));
            oValues.put("assigned_id", oJob.getString("assigned_id"));
            oValues.put("manifest_num", oJob.getString("manifest_num"));
            oValues.put("container_num", oJob.getString("container_num"));
            oValues.put("delivery_address_line1", oJob.getString("delivery_address_line1"));
            oValues.put("delivery_address_line2", oJob.getString("delivery_address_line2"));
            oValues.put("delivery_city", oJob.getString("delivery_city"));
            oValues.put("delivery_state", oJob.getString("delivery_state"));
            oValues.put("delivery_postal_code", oJob.getString("delivery_postal_code"));
            oValues.put("pickup_address_line1", oJob.getString("pickup_address_line1"));
            oValues.put("pickup_address_line2", oJob.getString("pickup_address_line2"));
            oValues.put("pickup_city", oJob.getString("pickup_city"));
            oValues.put("pickup_state", oJob.getString("pickup_state"));
            oValues.put("pickup_postal_code", oJob.getString("pickup_postal_code"));
            oValues.put("username", oJob.getString("username"));
            oValues.put("importer_id", oJob.getString("importer_id"));
            oValues.put("importer_name", oJob.getString("importer_name"));
            oValues.put("job_num", oJob.getString("job_num"));
            oValues.put("pickup_order_doc_name", oJob.getString("pickup_order_doc_name"));
            oValues.put("pickup_date_time", oJob.getString("pickup_date_time"));
            oValues.put("delivery_date_time", oJob.getString("delivery_date_time"));
            oValues.put("ref_note", oJob.getString("ref_note"));
            oValues.put("cargo_weight", oJob.getString("cargo_weight"));
            oValues.put("measurement_type_id", oJob.getString("measurement_type_id"));
            CTSDBHelper oDB = new CTSDBHelper(oContext, sDBName, null, iVersionVal);
            try {
                oDB.createDataBase();
            } catch (IOException ioe) {
                throw new Error("Unable to create database");
            }

            oDB.openDataBase();
            //The job object is good because we got here now delete the job and insert the new
            boolean bupdateSuccessfull = true;
            try {
                // need to see if this job is being reassigned
                if (checkCurrentJobAssign(oJob.getString("job_id"), oJob.getString("assigned_id"))) {
                    String sWhereClause = "job_id='" + oJob.getString("job_id") + "'";
                    oDB.updateRecordsInDB("jobs", sWhereClause, oValues);
                    //oDB.deleteRecordInDB("jobs", sWhereClause);
                    //oDB.insertRecordsInDB("jobs", null, oValues);
                    if (oValues.get("pickup_order_doc_name").toString().length() > 2) {
                        String sFilename = oValues.get("pickup_order_doc_name").toString();
                        File fFullpath = new File(getFilePath(), sFilename);
                        if (!fileExists(fFullpath)) {
                            //Only try to get the file if we do not already have it
                            DBParameters oDBParameters = new DBParameters();
                            String serverFileURL = oDBParameters.readParameter(
                                    "REST_BASE_URL", oContext, sDBName,
                                    iVersionVal);
                            serverFileURL += "files/" + sFilename;
                            SyncFiles.sWebService = serverFileURL;
                            SyncFiles.fFilePath = getFilePath();
                            SyncFiles.oContext = oContext;
                            SyncFiles.sFileName = sFilename;
                            SyncFiles.downloadFile();
                        }
                    }

                } else {
                    String sWhereClause = "job_id='" + oJob.getString("job_id") + "'";
                    oDB.deleteRecordInDB("jobs",sWhereClause);
                }

            } catch (Exception sqlEx) {
                bupdateSuccessfull = false;
                DBLogs.insert("SQL Error: " + sqlEx.toString(),
                        "SyncJobs.UpdateJob.1", oContext,
                        sDBName, iVersionVal);
            } finally {
                oDB.close();
            }
            // Doing this here because we are still inside the json try catch
            if (bupdateSuccessfull == true) {
                SyncJson oDeleteJobUpdate = new SyncJson();
                oDeleteJobUpdate.oContext = oContext;
                oDeleteJobUpdate.webserviceName = "gotJob.php";
                JSONObject oJobUpdateToDelete = new JSONObject();
                oJobUpdateToDelete.put("jobID", oJob.getString("job_id"));
                oDeleteJobUpdate.sendString = oJobUpdateToDelete.toString();
                if (!oDeleteJobUpdate.SyncData().equals("success")) {
                    DBLogs.insert("Delete of the job from server table updated_job_list failed",
                            "SyncJobs.UpdateJob.2", oContext,
                            sDBName, iVersionVal);
                };
            }
        } catch (JSONException ex) {
            DBLogs.insert("JSON Error: " + ex.toString(),
                    "SyncJobs.UpdateJob.3", oContext,
                    sDBName, iVersionVal);
        }
    }

    private static boolean fileExists(File file) {
        boolean bRtnValue = false;
        if(file.exists()) {
            bRtnValue = true;
        }
        return bRtnValue;
    }

    private static File getFilePath() {
        File filePath = oContext.getDir("jobs", Context.MODE_PRIVATE);
        return filePath;
    }

    /*
    * Returns estimated value of the lightness of the status bar background
    * @return
            */
    private static int getStatusBarBackgroundLightValue()
    {
        // better this than nothing
        Drawable bg = oContext.getResources().getDrawable(android.R.drawable.status_bar_item_background);
        int height = Math.max(1, bg.getIntrinsicHeight());
        int width = Math.max(1, bg.getIntrinsicWidth());
        Bitmap bitmap = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(bitmap);
        bg.setBounds(0, 0, width, height);
        bg.draw(canvas);

        long sum = 0;
        for (int x=0; x<width; x++){
            for (int y=0; y<height; y++){
                int color = bitmap.getPixel(x, y);
                int r = (color >> 16) & 0xFF;
                int g = (color >> 8) & 0xFF;
                int b = (color) & 0xFF;
                int max = Math.max(r, Math.max(g, b));
                int min = Math.min(r, Math.min(g, b));
                int l = (min + max)/2;
                sum = sum + l;
            }
        }
        bitmap.recycle();
        bitmap = null;
        canvas = null;
        bg = null;
        sum = sum / (width * height);
        // should be [0..255]
        return (int)Math.min(255, Math.max(sum, 0));
    }

    // this method will check to see if this is a change in job assignment
    private static Boolean checkCurrentJobAssign(String sJobID, String sAssignID) {
        Boolean bRtnVal = true;
        ArrayList<ArrayList<String>> jobArray;
        DateConvertClass oDateConvertClass = new DateConvertClass();
        oDateConvertClass.oContext = oContext;
        String sCurrentDateTime = oDateConvertClass.GMTTimestamp();

        // get the current job data
        String data = "";
        CTSDBHelper oDB = new CTSDBHelper(oContext, sDBName, null, iVersionVal);
        try {
            oDB.createDataBase();
        } catch (IOException ioe) {
            throw new Error("Unable to create database");
        }

        oDB.openDataBase();

        String sSQL = "select * from jobs where job_id = '" + sJobID + "'";

        Log.d("sSQL", sSQL);

        jobArray = oDB.selectRecordsFromDBList(sSQL, null);

        Jobs jobObj = new Jobs();
        for (ArrayList<String> sValue : jobArray) {
            jobObj.job_id = sValue.get(1);
            jobObj.job_status_id = sValue.get(3);
            //Convert the GMT time that is in the database to local device time
            jobObj.date_time = oDateConvertClass.GMTToLocal(sValue.get(2));
            jobObj.status_name = sValue.get(4);
            jobObj.assigned_id = sValue.get(5);
            jobObj.importer_id = sValue.get(19);
            jobObj.importer_name = sValue.get(20);
            jobObj.manifest_num = sValue.get(6);
            jobObj.container_num = sValue.get(7);
            jobObj.delivery_address_line1 = sValue.get(8);
            jobObj.delivery_address_line2 = sValue.get(9);
            jobObj.delivery_city = sValue.get(10);
            jobObj.delivery_state = sValue.get(11);
            jobObj.delivery_postal_code = sValue.get(12);
            jobObj.pickup_address_line1 = sValue.get(13);
            jobObj.pickup_address_line2 = sValue.get(14);
            jobObj.pickup_city = sValue.get(15);
            jobObj.pickup_state = sValue.get(16);
            jobObj.pickup_postal_code = sValue.get(17);
            jobObj.username = sValue.get(18);
            jobObj.job_num = sValue.get(21);
            jobObj.pickup_date_time = oDateConvertClass.GMTToLocal(sValue.get(23));
            jobObj.delivery_date_time = oDateConvertClass.GMTToLocal(sValue.get(24));
            jobObj.ref_note = sValue.get(25);
            jobObj.cargo_weight = sValue.get(26);
            jobObj.measurement_type_id = sValue.get(27);
        }

        // closes the database
        try {
            oDB.close();
        } catch (Throwable e) {
            e.printStackTrace();
        }

        if (jobObj.assigned_id != sAssignID) {
            bRtnVal = false;
        }

        return bRtnVal;
    }

    public static String getSignatureNames(String sJobID) {
        String sRtnVal = "";
        ArrayList<ArrayList<String>> jobArray;

        String data = "";
        CTSDBHelper oDB = new CTSDBHelper(oContext, sDBName, null, iVersionVal);
        try {
            oDB.createDataBase();
        } catch (IOException ioe) {
            throw new Error("Unable to create database");
        }

        oDB.openDataBase();

        String sSQL = "select pickup_signature_name, delivery_signature_name from jobs where job_num = '" + sJobID + "'";

        Log.d("sSQL", sSQL);

        jobArray = oDB.selectRecordsFromDBList(sSQL, null);
        String sPickupSignatureName = "";
        String sDeliverySignatureName = "";
        for (ArrayList<String> sValue : jobArray) {
            sPickupSignatureName = sValue.get(0);
            sDeliverySignatureName = sValue.get(1);
        }

        // closes the database
        try {
            oDB.close();
        } catch (Throwable e) {
            e.printStackTrace();
        }

        // build JSON object
        JSONObject oSigJob = new JSONObject();
        try {
            oSigJob.put("pickup_signature_name", sPickupSignatureName);
            oSigJob.put("delivery_signature_name", sDeliverySignatureName);
            oSigJob.put("jobID",sJobID);

            sRtnVal = oSigJob.toString();
        } catch (Exception ex) {

        }

        // return the object

        return sRtnVal;
    }
}
